netapp_ontap.models.storage_unit_anti_ransomware_entropy_stats_response_records API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.storage_unit_anti_ransomware_entropy_stats_response_records`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class StorageUnitAntiRansomwareEntropyStatsResponseRecordsSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the StorageUnitAntiRansomwareEntropyStatsResponseRecords object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `data_written_in_bytes: Size GET`

    The amount of data written.

  `duration: str GET`

    The duration of the interval associated with this statistic. The duration is represented in ISO-8601 standard format.

    Example: PT15M

  `encryption_percentage: Size GET`

    The percentage of data that is encrypted.

  `entropy_stats_type: str GET POST PATCH`

    Storage unit metrics are retrieved based on this statistic type.

    Valid choices:

    - sub_hourly
    - hourly
    - daily
    - high_enc_pct
  `links: SelfLink GET`

    The links field of the storage_unit_anti_ransomware_entropy_stats_response_records.

  `storage_unit: StorageUnit GET POST PATCH`

    The storage_unit field of the storage_unit_anti_ransomware_entropy_stats_response_records.

  `timestamp: ImpreciseDateTime GET POST PATCH`

    Start time in date-time format.